@@ -16,7 +16,7 @@ catalog_file_description = """
         'catalog_file_description': '<this description>',
         'modified': '<YYYY-MM-DDThh:mm:ss.ssssss>',  # UTC time of last-modified record in this file
         'records': {  # Includes *all* records published on Zenodo in the 'sxs' community, not just simulations
-            '<id>': {  # This Zenodo ID key is a *string* containing the 'id' value inside this object (JSON requires keys to be strings)
+            '<doi_url>': {  # This is precisely the value of the 'doi_url' key below
                 # More details about this 'representation' object at http://developers.zenodo.org/#depositions
                 'conceptdoi': '10.5281/zenodo.<conceptrecid>',  # Permanent DOI for all versions of this record
                 'conceptrecid': '<conceptrecid>',  # ~7-digit integer (as string) collectively identifying all versions of this record
@@ -171,7 +171,7 @@ def _create_simulations_skeleton(record_list):
         sxs_id(r.get('title', '')): {
             'url': r['links']['conceptdoi'],
             'metadata_file_info': max([f for f in r.get('files', []) if '/metadata.json' in f['filename']],
-                                      default={}, key=lambda f:f['filename'])
+                                      default={}, key=lambda f: f['filename'])
         }
         for r in record_list if sxs_id(r.get('title', ''))
     }
@@ -180,7 +180,7 @@ def _create_simulations_skeleton(record_list):
 def _download_sxs_metadata(login, simulations):
     """Download metadata.json from Zenodo for each simulation, if needed"""
     import traceback
-    from tqdm.autonotebook import tqdm
+    from tqdm.auto import tqdm
     for sxs_id in tqdm(simulations, dynamic_ncols=True):
         download_url = simulations[sxs_id].get('metadata_file_info', {}).get('links', {}).get('download', '')
         if not download_url:
@@ -195,63 +195,12 @@ def _download_sxs_metadata(login, simulations):
             traceback.print_exc()
 
 
-def read(path='~/.sxs/catalog', download_if_not_found=True):
-    """Read a local copy of the SXS catalog from Zenodo
-
-    Parameters
-    ==========
-    path: str, optional [defaults to '~/.sxs/catalog']
-        Absolute or relative path to JSON file containing the complete catalog.  If the path does
-        not end with '.json', it is assumed to be a directory containing a 'private_catalog.json',
-        'public_catalog.json', or 'catalog.json' file.
-    download_if_not_found: bool, optional [defaults to True]
-        If the above path does not contain any of the recognized files, the public version will
-        be downloaded from https://data.black-holes.org/catalog.json.
-
-    Returns
-    =======
-    catalog: dict
-       This is the dictionary corresponding to the contents of the JSON file.  Note that, as
-       described in `sxs.zenodo.catalog.catalog_file_description`, the top level contains just
-       four keys: 'catalog_file_description', 'modified', 'records', and 'simulations'.  You may
-       want to follow this function call with something like
-           records, simulations = catalog['records'], catalog['simulations']
-
-    """
-    from os.path import expanduser, join, exists, dirname
-    import json
-    from ..utilities import download
-
-    # Make sure that the catalog file exists
-    path = expanduser(path)
-    if not path.endswith('.json'):
-        new_path = join(path, 'private_catalog.json')
-        if not exists(new_path):
-            new_path = join(path, 'public_catalog.json')
-        if not exists(new_path):
-            new_path = join(path, 'catalog.json')
-        path = new_path
-    if not exists(path):
-        msg = "Could not find catalog file in '{0}'.".format(dirname(path))
-        if download_if_not_found:
-            print(msg + '  Downloading to that directory now.')
-            download('https://data.black-holes.org/catalog.json', path)
-        else:
-            raise ValueError(msg)
-
-    # Read the catalog file
-    with open(path, 'r') as f:
-        catalog = json.load(f)
-
-    return catalog
-
-
 def create(login=None):
     """Create the catalog from scratch
 
-    This function will take quite some time (more than 15 minutes), because it has to download
-    each metadata file individually, which necessarily requires a separate Zenodo request
-    for each download.
+    This function will take quite some time (more than 15 minutes), because it has
+    to download each metadata file individually, which necessarily requires a
+    separate Zenodo request for each download.
 
     """
     from textwrap import dedent
@@ -261,7 +210,7 @@ def create(login=None):
     l = login or Login()
 
     # Get the list of all SXS records from Zenodo
-    records = l.search(q='communities:sxs')
+    records = l.search(q='communities:sxs', all_versions=True, status='published', size=9000)
 
     # Closed-access records don't have their files included by default; add them
     records = [_include_file_data(l, record) for record in records]
@@ -283,14 +232,14 @@ def create(login=None):
     catalog = {
         'catalog_file_description': dedent(catalog_file_description).split('\n')[1:-1],
         'modified': modified,
-        'records': {r['links']['conceptdoi']: r for r in records},
+        'records': {r['doi_url']: r for r in records},
         'simulations': simulations
     }
     return catalog
 
 
 def split_catalog(catalog):
-    """Split catalog four ways: private vs. public, and complete vs. just simulations
+    """Split catalog four ways: private/public, and complete/simulations
 
     This function splits the catalog into four separate parts:
 
@@ -299,12 +248,13 @@ def split_catalog(catalog):
       3) The complete catalog for all systems
       4) The SXS metadata for all systems
 
-    The complete catalog contains all Zenodo metadata and SXS metadata, as well as a description of
-    the catalog and the most recent modification time.  The simulations are useful for serving data
-    used in the waveform index table at <https://data.black-holes.org/waveforms/catalog.html>,
-    because it is significantly less data.  The private data can be served via the wiki, with the
-    public data as a fallback if the user's web browser does not send credentials along with the
-    request for the data.
+    The complete catalog contains all Zenodo metadata and SXS metadata, as well as
+    a description of the catalog and the most recent modification time.  The
+    simulations are useful for serving data used in the waveform index table at
+    <https://data.black-holes.org/waveforms/catalog.html>, because it is
+    significantly less data.  The private data can be served via the wiki, with the
+    public data as a fallback if the user's web browser does not send credentials
+    along with the request for the data.
 
     """
     import copy
@@ -334,31 +284,34 @@ def write_split_catalogs(catalog, public_dir='~/.sxs/catalog/', private_dir='~/.
                          public_prefix='', private_prefix=''):
     """Write four versions of the catalog to files
 
-    The input catalog is first split into four parts by `split_catalog` (see that function's
-    docstring for details).  These will be written into four separate JSON files.  If the public and
-    private directories input as arguments to this function are the same, the files will be named
-    private_catalog.json, private_simulations.json, public_catalog.json, and
-    public_simulations.json.  Otherwise, the prefixes will be removed so that the files are named
-    either catalog.json or simulations.json when placed in their respective directories.
+    The input catalog is first split into four parts by `split_catalog` (see that
+    function's docstring for details).  These will be written into four separate
+    JSON files.  If the public and private directories input as arguments to this
+    function are the same, the files will be named private_catalog.json,
+    private_simulations.json, public_catalog.json, and public_simulations.json.
+    Otherwise, the prefixes will be removed so that the files are named either
+    catalog.json or simulations.json when placed in their respective directories.
 
     Parameters
-    ==========
-    catalog: dict
-        The catalog in the standard format output by functions in this submodule, and described in
-        `sxs.zenodo.catalog.catalog_file_description`.
-    public_dir: str, optional [defaults to '~/.sxs/catalog/']
+    ----------
+    catalog : dict
+        The catalog in the standard format output by functions in this submodule,
+        and described in `sxs.zenodo.catalog.catalog_file_description`.
+    public_dir : str, optional [defaults to '~/.sxs/catalog/']
     private_dir: str, optional [defaults to '~/.sxs/catalog/']
-        Absolute or relative paths to the directory in which the files will be written.  If they do
-        not exist, they will be created.  Note that, as explained above, the output file names will
-        depend on whether these two arguments are the same or different.
+        Absolute or relative paths to the directory in which the files will be
+        written.  If they do not exist, they will be created.  Note that, as
+        explained above, the output file names will depend on whether these two
+        arguments are the same or different.
     public_prefix: str, optional [defaults to '']
     private_prefix: str, optional [defaults to '']
-        Strings to be prepended to the output file names.  If these are empty strings but the output
-        directories are the same, these are set to 'public_' and 'private_', respectively.
+        Strings to be prepended to the output file names.  If these are empty
+        strings but the output directories are the same, these are set to 'public_'
+        and 'private_', respectively.
 
     """
     import os
-    from os.path import expanduser, normpath, join, exists, dirname
+    from os.path import expanduser, normpath, join
     from datetime import datetime
     import json
 
@@ -419,22 +372,22 @@ def update(login=None, path='~/.sxs/catalog/private_catalog.json',
            nginx_map_file_path='~/.sxs/catalog/sxs_to_zenodo.map'):
     """Update a local copy of the SXS catalog from Zenodo
 
-    Note: This function works in place, by overwriting the input catalog file, as well as the other
-    three versions of it produced by `split_catalog`.
+    Warning: This function works in place, by overwriting the input catalog file,
+    as well as the other three versions of it produced by `split_catalog`.
 
     Parameters
-    ==========
-    login: sxs.zenodo.Login object, optional [defaults to new Login object]
+    ----------
+    login : sxs.zenodo.Login object, optional [defaults to new Login object]
         This is used to query Zenodo for new data.
-    path: str, optional [defaults to '~/.sxs/catalog/private_catalog.json']
+    path : str, optional [defaults to '~/.sxs/catalog/private_catalog.json']
         Absolute or relative path to JSON file containing the complete catalog.  If the path does
         not end with '.json', it is assumed to be a directory containing a 'catalog.json' or
         'private_catalog.json' file.
-    public_out_dir: str, optional [defaults to '~/.sxs/catalog/']
-    private_out_dir: str, optional [defaults to '~/.sxs/catalog/']
+    public_out_dir : str, optional [defaults to '~/.sxs/catalog/']
+    private_out_dir : str, optional [defaults to '~/.sxs/catalog/']
         These are passed to the `save_split_catalogs` function; see that function's docstring for
         details.
-    nginx_map_file_path: str, optional [defaults to '~/.sxs/catalog/sxs_to_zenodo.map']
+    nginx_map_file_path : str, optional [defaults to '~/.sxs/catalog/sxs_to_zenodo.map']
         This is passed to the `nginx_map` function, which produces a map file to be used by nginx to
         redirect requests for, e.g., https://data.black-holes.org/SXS:BBH:0001 to the appropriate
         Zenodo concept-doi page.
@@ -464,14 +417,17 @@ def update(login=None, path='~/.sxs/catalog/private_catalog.json',
     l = login or Login()
 
     # Get the list of all SXS records from Zenodo
-    zenodo_records = {r['links']['conceptdoi']: r for r in l.search(q='communities:sxs') if 'conceptdoi' in r['links']}
+    zenodo_records = {
+        r['doi_url']: r
+        for r in l.search(q='communities:sxs', all_versions=True, status='published', size=9000)
+    }
 
     # Loop through the zenodo records, ensuring that they are all present and current in the old records
     catalog_changed = False
     for r in zenodo_records:
         if r not in records or zenodo_records[r].get('modified', 0) != records[r].get('modified', 1):
             records[r] = _include_file_data(l, zenodo_records[r])
-            new_simulation = _create_simulations_skeleton([records[r],])
+            new_simulation = _create_simulations_skeleton([records[r], ])
             simulations.update(new_simulation)
             catalog_changed = True
 
@@ -484,7 +440,7 @@ def update(login=None, path='~/.sxs/catalog/private_catalog.json',
 
         # Write the various catalog files
         write_split_catalogs(catalog, public_dir=public_out_dir, private_dir=private_out_dir,
-                             public_prefix='public_', private_prefix = 'private_')
+                             public_prefix='public_', private_prefix='private_')
 
         # Update the SXS-to-zenodo map
         sxs_id_to_conceptrecid = {sxsid: doi.replace('https://doi.org/10.5281/zenodo.', '')
@@ -502,7 +458,7 @@ def sxs_metadata_file_description(representation):
     """Find metadata file from highest Lev for this simulation"""
     from os.path import basename
     files = representation.get('files', [])
-    metadata_files = [f for f in files if basename(f.get('filename', ''))=='metadata.json']
+    metadata_files = [f for f in files if basename(f.get('filename', '')) == 'metadata.json']
     metadata_files = sorted(metadata_files, key=lambda f: f['filename'])
     if not metadata_files:
         return None
@@ -518,33 +474,35 @@ def fetch_metadata(url, login=None, *args, **kwargs):
         return {}
     try:
         return r.json()
-    except:
+    except Exception:
         return {}
 
 
 def nginx_map(sxs_id_to_conceptrecid, map_file_path=None):
     """Create a mapping from SXS identifiers to Zenodo record numbers for nginx
 
-    The input must be a catalog file.  The output is formatted for inclusion into an nginx
-    configuration.  Note that this map file includes a `map_hash_max_size` directive, and thus must
-    precede any `map` directives, or you will get an error that this directive is a duplicate (even
-    if you never explicitly gave it previously).
+    The input must be a catalog file.  The output is formatted for inclusion into
+    an nginx configuration.  Note that this map file includes a `map_hash_max_size`
+    directive, and thus must precede any `map` directives, or you will get an error
+    that this directive is a duplicate (even if you never explicitly gave it
+    previously).
 
     The output map matches the plain SXS identifier (with nothing following it).
 
     Parameters
-    ==========
-    sxs_id_to_conceptrecid: dict
+    ----------
+    sxs_id_to_conceptrecid : dict
         A dictionary mapping SXS IDs to Zenodo's concept-record IDs.
-    map_file_path: None or string [defaults to None]
-        Relative or absolute path to the nginx map file to be output.  If `None`, the function first
-        attempts to write the file into '~/.sxs/catalog/sxs_to_zenodo.map'; if that is not possible,
-        it tries to write to the same file in the current working directory.
+    map_file_path : None or string [defaults to None]
+        Relative or absolute path to the nginx map file to be output.  If `None`,
+        the function first attempts to write the file into
+        '~/.sxs/catalog/sxs_to_zenodo.map'; if that is not possible, it tries to
+        write to the same file in the current working directory.
 
     """
-    from os.path import expanduser, exists, join, dirname
-    import json
+    from os.path import expanduser
     import math
+
     def touch(fname, times=None):
         from os import utime
         try:
@@ -566,7 +524,6 @@ def nginx_map(sxs_id_to_conceptrecid, map_file_path=None):
         map_file_path = expanduser(map_file_path)
     # Figure out how to construct the output
     size = 64 * 2**math.ceil(math.log2(len(sxs_id_to_conceptrecid)+1))  # nginx needs this to know the hash size
-    record_string = "  {0} {1};\n"
     # Construct the output
     with open(map_file_path, 'w') as f:
         f.write("map_hash_max_size {0};\n".format(size))
@@ -578,18 +535,19 @@ def nginx_map(sxs_id_to_conceptrecid, map_file_path=None):
 
 
 def resolutions_for_simulation(sxs_id, sxs_catalog):
-    """List the available resolutions for a given sxs_id and sxs catalog metadata
+    """List available resolutions for a given sxs_id and sxs catalog metadata
 
     Parameters
-    ==========
-    sxs_id: str
+    ----------
+    sxs_id : str
         This should be a key in the sxs_catalog['simulations'] dictionary.
-    sxs_catalog: dict
+    sxs_catalog : dict
 
     Returns
-    =======
-    resolutions: list
-        Sorted list of integers representing the Levs available for the given SXS ID.
+    -------
+    resolutions : list
+        Sorted list of integers representing the Levs available for the given SXS
+        ID.
 
     """
     from .. import lev_number
@@ -608,13 +566,14 @@ def resolutions_for_simulations(sxs_catalog):
     """Map available SXS IDs to corresponding available resolutions
 
     Parameters
-    ==========
-    sxs_catalog: dict
+    ----------
+    sxs_catalog : dict
 
     Returns
-    =======
-    map_sxs_id_to_resolutions: dict
-        Maps each SXS ID to a sorted list of integers representing the Levs available for it.
+    -------
+    map_sxs_id_to_resolutions : dict
+        Maps each SXS ID to a sorted list of integers representing the Levs
+        available for it.
 
     """
     return {
