@@ -6,11 +6,12 @@ import h5py
 import pytest
 import sxs
 
+# see test_utilities.py for explanation
 shortest_h_com_file = "SXS:BBH:0156v1/Lev5/rhOverM_Asymptotic_GeometricUnits_CoM.h5"
 
 
 def test_backwards_compatibility():
-    path = sxs.sxs_directory("cache") / shortest_h_com_file
+    path = sxs.sxs_directory("cache") / sxs.utilities.sxs_path_to_system_path(shortest_h_com_file)
     with contextlib.redirect_stdout(None):
         with sxs.loadcontext(shortest_h_com_file) as h:
             with h5py.File(path, "r") as f:
